package com.example.rfid14443a;

import java.util.ArrayList;

import com.example.rfid14443a.fragment.M1Fragment;
import com.example.rfid14443a.fragment.Scan14443AFragment;
import com.example.rfid14443a.fragment.UltralightFragment;
import com.rscja.deviceapi.Barcode2D;
import com.rscja.deviceapi.RFIDWithISO14443A;
import com.rscja.deviceapi.exception.ConfigurationException;
import com.rscja.utility.StringUtility;

import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentTabHost;
import android.app.Activity;
import android.app.ProgressDialog;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;
import android.os.Build;

/**
 * RFID14443A使用demo
 * 
 * 1、使用前请确认您的机器已安装此模块。 
 * 2、要正常使用模块需要在\libs\armeabi\目录放置libDeviceAPI.so文件，同时在\libs\目录下放置DeviceAPIver20160627.jar文件。 
 * 3、在操作设备前需要调用 init() 打开设备，使用完后调用 free() 关闭设备
 * 
 * 更多函数的使用方法请查看API说明文档
 * 
 * @author wushengjun	
 * 更新于2016年8月9日
 */

public class MainActivity extends FragmentActivity {

	private final static String TAG = "MainActivity";

	public RFIDWithISO14443A mRFID;

	private FragmentTabHost mTabHost;
	private FragmentManager fm;

	boolean bResult = false;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		fm = getSupportFragmentManager();
		mTabHost = (FragmentTabHost) findViewById(android.R.id.tabhost);
		mTabHost.setup(this, fm, R.id.realtabcontent);

		mTabHost.addTab(mTabHost.newTabSpec("scan").setIndicator("Scan"),
				Scan14443AFragment.class, null);
		mTabHost.addTab(mTabHost.newTabSpec("M1").setIndicator("M1"),
				M1Fragment.class, null);
		mTabHost.addTab(mTabHost.newTabSpec("ul").setIndicator("Ultra light"),
				UltralightFragment.class, null);

		try {
			mRFID = RFIDWithISO14443A.getInstance();
		} catch (ConfigurationException e) {

			
			Toast.makeText(MainActivity.this, R.string.rfid_mgs_error_config,
					Toast.LENGTH_SHORT).show();
			return;
		}

	}
	
	
	@Override
	protected void onPause() {
		// TODO Auto-generated method stub
		super.onPause();

		mRFID.free();

	}

	@Override
	protected void onResume() {
		// TODO Auto-generated method stub
		super.onResume();

		new InitTask().execute();

	}

	/**
	 * 设备上电异步类
	 * 
	 * @author liuruifeng 2014年8月6日
	 */	
	public class InitTask extends AsyncTask<String, Integer, Boolean> {
		ProgressDialog mypDialog;
		
		@Override
		protected Boolean doInBackground(String... params) {
			// TODO Auto-generated method stub
			return mRFID.init();
		}

		@Override
		protected void onPostExecute(Boolean result) {
			super.onPostExecute(result);

			mypDialog.cancel();

			if (!result) {
				Toast.makeText(MainActivity.this, "init fail",
						Toast.LENGTH_SHORT).show();
			}
		}

		@Override
		protected void onPreExecute() {
			// TODO Auto-generated method stub
			super.onPreExecute();

			mypDialog = new ProgressDialog(MainActivity.this);
			mypDialog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
			mypDialog.setMessage("init...");
			mypDialog.setCanceledOnTouchOutside(false);
			mypDialog.show();
		}

	}
	
	public ArrayList<String> builNum(int count) {
		if (count < 1) {
			return null;

		}

		ArrayList<String> arrStr = new ArrayList<String>();

		for (int i = 0; i < count; i++) {
			arrStr.add(String.valueOf(i));

		}
		return arrStr;
	}
	
	/**
	 * 将ScrollView根据内部控件高度定位到底端
	 * 
	 * @param scroll
	 * @param inner
	 */
	public void scrollToBottom(final View scroll, final View inner) {

		Handler mHandler = new Handler();

		mHandler.post(new Runnable() {
			public void run() {
				if (scroll == null || inner == null) {
					return;
				}
				int offset = inner.getMeasuredHeight() - scroll.getHeight();
				if (offset < 0) {
					offset = 0;
				}

				scroll.scrollTo(0, offset);
			}
		});
	}
	
	/**
	 * 验证十六进制输入是否正确
	 * 
	 * @param str
	 * @return
	 */
	public boolean vailHexInput(String str) {

		if (str == null || str.length() == 0) {
			return false;
		}

		// 长度必须是偶数
		if (str.length() % 2 == 0) {
			return StringUtility.isHexNumberRex(str);
		}

		return false;
	}
	
	/**
	 * 字符串转整数
	 * 
	 * @param str
	 * @param defValue
	 * @return
	 */
	public int toInt(String str, int defValue) {
		try {
			return Integer.parseInt(str);
		} catch (Exception e) {
		}
		return defValue;
	}
}
